![Square dodging some bullets](https://notabug.org/jorgesumle/bullet_dodger/raw/master/screenshots/playing.png)

Fun and challenging mouse game where you must dodge bullets. How many
points will you get?

Installation
============

This game requires Python and [pygame](http://pygame.org/).

Installing from source
----------------------

1.  Install Python 3
2.  Install pygame for Python 3 (version 1.9.2 or greater)
3.  Clone the repository:
    `git clone https://notabug.org/jorgesumle/bullet_dodger`
4.  Execute the file `run_bullet_dodger.py`: with
    `./bullet_dodger/run_bullet_dodger.py` or
    `python3 bullet_dodger/run_bullet_dodger.py`

Installing with pip
-------------------

You can install the game using pip: `pip install bullet_dodger`. Once
you have installed the game successfully with pip, you can run it
executing `bullet_dodger`.

How to play
===========

![Start screen](https://notabug.org/jorgesumle/bullet_dodger/raw/master/screenshots/instructions.png)

Use the mouse to control your character. Press any mouse button to
teleport to a random location.

License
=======

This game is free software. It uses the [GNU General Public License,
version
3](https://notabug.org/jorgesumle/bullet_dodger/raw/master/LICENSE). The
licenses of music, artwork, sounds, etc. can be found in the file
[ATTRIBUTIONS.md](https://notabug.org/jorgesumle/bullet_dodger/src/master/ATTRIBUTIONS.md).
